@@ -47,7 +47,7 @@ static void qsf_object_commitCB (gpointer key, gpointer value,
 struct QSFBackend_s
 {
 	QofBackend be;
-	qsf_param *params;
+	QsfParam *params;
 	gchar *fullpath;
 };
 
@@ -56,9 +56,9 @@ typedef struct QSFBackend_s QSFBackend;
 static void
 option_cb (QofBackendOption * option, gpointer data)
 {
-	qsf_param *params;
+	QsfParam *params;
 
-	params = (qsf_param *) data;
+	params = (QsfParam *) data;
 	g_return_if_fail (params);
 	if (0 == safe_strcmp (QSF_COMPRESS, option->option_name))
 	{
@@ -86,7 +86,7 @@ static void
 qsf_load_config (QofBackend * be, KvpFrame * config)
 {
 	QSFBackend *qsf_be;
-	qsf_param *params;
+	QsfParam *params;
 
 	ENTER (" ");
 	qsf_be = (QSFBackend *) be;
@@ -101,7 +101,7 @@ qsf_get_config (QofBackend * be)
 {
 	QofBackendOption *option;
 	QSFBackend *qsf_be;
-	qsf_param *params;
+	QsfParam *params;
 
 	if (!be)
 	{
@@ -174,7 +174,7 @@ qsf_map_prepare_list (GList ** maps)
 }
 
 static void
-qsf_param_init (qsf_param * params)
+qsf_param_init (QsfParam * params)
 {
 	gchar *qsf_time_string;
 	gchar *qsf_enquiry_date;
@@ -248,6 +248,14 @@ qsf_param_init (qsf_param * params)
 		qsf_time_string);
 	/* default map files */
 	params->map_files = *qsf_map_prepare_list (&params->map_files);
+	params->err_nomap = qof_error_register 
+	(_("The selected QSF Object file '%s' requires a "
+	"map but it was not provided."), TRUE);
+	params->err_overflow = qof_error_register
+	(_("When converting XML strings into numbers, an "
+	 "overflow has been detected. The QSF object file "
+	 "'%s' contains invalid data in a field that is "
+	 "meant to hold a number."), TRUE);
 }
 
 static gboolean
@@ -260,7 +268,17 @@ qsf_determine_file_type (const gchar * path)
 	if (0 == safe_strcmp (path, QOF_STDOUT))
 		return TRUE;
 	if (stat (path, &sbuf) < 0)
+	{
+	/* in case the error is that the file does not exist */
+		FILE * f;
+		f = fopen (path, "a+");
+		if (f)
+		{
+			fclose (f);
+			return TRUE;
+		}
 		return FALSE;
+	}
 	if (sbuf.st_size == 0)
 		return TRUE;
 	if (is_our_qsf_object (path))
@@ -272,9 +290,6 @@ qsf_determine_file_type (const gchar * path)
 	return FALSE;
 }
 
-/* GnuCash does LOTS of filesystem work, QSF is going to leave most of it to libxml2. :-)
-Just strip the file: from the start of the book_path URL. Locks are not implemented.
-*/
 static void
 qsf_session_begin (QofBackend * be, QofSession * session,
 	const gchar * book_path, gboolean ignore_lock,
@@ -293,8 +308,8 @@ qsf_session_begin (QofBackend * be, QofSession * session,
 	qsf_be->fullpath = NULL;
 	if (book_path == NULL)
 	{
-		/* use stdout */
-		qof_backend_set_error (be, ERR_BACKEND_NO_ERR);
+		/* allow use of stdout */
+		qof_error_set_be (be, QOF_SUCCESS);
 		return;
 	}
 	p = strchr (book_path, ':');
@@ -303,7 +318,7 @@ qsf_session_begin (QofBackend * be, QofSession * session,
 		path = g_strdup (book_path);
 		if (!g_ascii_strncasecmp (path, "file:", 5))
 		{
-			p = g_new (gchar, strlen (path) - 5 + 1);
+			p = g_new0 (gchar, strlen (path) - 5 + 1);
 			strcpy (p, path + 5);
 		}
 		qsf_be->fullpath = g_strdup (p);
@@ -320,15 +335,19 @@ qsf_session_begin (QofBackend * be, QofSession * session,
 			fclose (f);
 		else
 		{
-			qof_backend_set_error (be, ERR_BACKEND_READONLY);
+			qof_error_set_be (be, qof_error_register
+			(_("could not write to '%s'. "
+			 "That database may be on a read-only file system, "
+			 "or you may not have write permission for the "
+			"directory.\n"), TRUE));
 			return;
 		}
 	}
-	qof_backend_set_error (be, ERR_BACKEND_NO_ERR);
+	qof_error_set_be (be, QOF_SUCCESS);
 }
 
 static void
-qsf_free_params (qsf_param * params)
+qsf_free_params (QsfParam * params)
 {
 	g_hash_table_destroy (params->qsf_calculate_hash);
 	g_hash_table_destroy (params->qsf_default_hash);
@@ -363,14 +382,14 @@ qsf_destroy_backend (QofBackend * be)
 static void
 ent_ref_cb (QofEntity * ent, gpointer user_data)
 {
-	qsf_param *params;
+	QsfParam *params;
 	QofEntityReference *ref;
 	void (*reference_setter) (QofEntity *, QofEntity *);
 	QofEntity *reference;
 	QofCollection *coll;
 	QofIdType type;
 
-	params = (qsf_param *) user_data;
+	params = (QsfParam *) user_data;
 	g_return_if_fail (params);
 	while (params->referenceList)
 	{
@@ -398,9 +417,9 @@ ent_ref_cb (QofEntity * ent, gpointer user_data)
 static void
 insert_ref_cb (QofObject * obj, gpointer user_data)
 {
-	qsf_param *params;
+	QsfParam *params;
 
-	params = (qsf_param *) user_data;
+	params = (QsfParam *) user_data;
 	g_return_if_fail (params);
 	qof_object_foreach (obj->e_type, params->book, ent_ref_cb, params);
 }
@@ -410,10 +429,10 @@ insert_ref_cb (QofObject * obj, gpointer user_data)
 ==================================================*/
 
 static gboolean
-qsfdoc_to_qofbook (qsf_param * params)
+qsfdoc_to_qofbook (QsfParam * params)
 {
 	QofInstance *inst;
-	struct qsf_node_iterate qiter;
+	struct QsfNodeIterate qiter;
 	QofBook *book;
 	GList *object_list;
 	xmlNodePtr qsf_root;
@@ -457,7 +476,7 @@ qsfdoc_to_qofbook (qsf_param * params)
 */
 static gboolean
 load_qsf_object (QofBook * book, const gchar * fullpath,
-	qsf_param * params)
+				 QsfParam * params)
 {
 	xmlNodePtr qsf_root, map_root;
 	xmlDocPtr mapDoc, foreign_doc;
@@ -468,13 +487,14 @@ load_qsf_object (QofBook * book, const gchar * fullpath,
 	/* use selected map */
 	if (!map_file)
 	{
-		qof_backend_set_error (params->be, ERR_QSF_NO_MAP);
+		qof_error_set_be (params->be, params->err_nomap);
 		return FALSE;
 	}
 	foreign_doc = xmlParseFile (fullpath);
 	if (foreign_doc == NULL)
 	{
-		qof_backend_set_error (params->be, ERR_FILEIO_PARSE_ERROR);
+		qof_error_set_be (params->be, qof_error_register
+		(_("There was an error parsing the file '%s'.\n"), TRUE));
 		return FALSE;
 	}
 	qsf_root = NULL;
@@ -484,13 +504,13 @@ load_qsf_object (QofBook * book, const gchar * fullpath,
 	map_path = g_strdup_printf ("%s/%s", QSF_SCHEMA_DIR, map_file);
 	if (!map_path)
 	{
-		qof_backend_set_error (params->be, ERR_QSF_NO_MAP);
+		qof_error_set_be (params->be, params->err_nomap);
 		return FALSE;
 	}
 	mapDoc = xmlParseFile (map_path);
 	if (!mapDoc)
 	{
-		qof_backend_set_error (params->be, ERR_QSF_NO_MAP);
+		qof_error_set_be (params->be, params->err_nomap);
 		return FALSE;
 	}
 	map_root = xmlDocGetRootElement (mapDoc);
@@ -501,14 +521,15 @@ load_qsf_object (QofBook * book, const gchar * fullpath,
 }
 
 static gboolean
-load_our_qsf_object (const gchar * fullpath, qsf_param * params)
+load_our_qsf_object (const gchar * fullpath, QsfParam * params)
 {
 	xmlNodePtr qsf_root;
 
 	params->input_doc = xmlParseFile (fullpath);
 	if (params->input_doc == NULL)
 	{
-		qof_backend_set_error (params->be, ERR_FILEIO_PARSE_ERROR);
+		qof_error_set_be (params->be, qof_error_register
+		(_("There was an error parsing the file '%s'."), TRUE));
 		return FALSE;
 	}
 	qsf_root = NULL;
@@ -538,8 +559,8 @@ static void
 qsf_file_type (QofBackend * be, QofBook * book)
 {
 	QSFBackend *qsf_be;
-	QofBackendError err;
-	qsf_param *params;
+	QofErrorId parse_err;
+	QsfParam *params;
 	FILE *f;
 	gchar *path;
 	gboolean result;
@@ -550,24 +571,26 @@ qsf_file_type (QofBackend * be, QofBook * book)
 	g_return_if_fail (qsf_be != NULL);
 	g_return_if_fail (qsf_be->fullpath != NULL);
 	g_return_if_fail (qsf_be->params != NULL);
+	parse_err = qof_error_register
+		(_("There was an error parsing the file '%s'."), TRUE);
 	params = qsf_be->params;
 	params->book = book;
+	DEBUG (" qsf_be->fullpath=%s", qsf_be->fullpath);
 	path = g_strdup (qsf_be->fullpath);
 	f = fopen (path, "r");
 	if (!f)
-		qof_backend_set_error (be, ERR_FILEIO_READ_ERROR);
-	fclose (f);
+		qof_error_set_be (be, qof_error_register
+		(_("There was an error reading the file '%s'."), TRUE));
+	else
+		fclose (f);
 	params->filepath = g_strdup (path);
-	qof_backend_get_error (be);
 	result = is_our_qsf_object_be (params);
 	if (result)
 	{
 		params->file_type = OUR_QSF_OBJ;
 		result = load_our_qsf_object (path, params);
 		if (!result)
-		{
-			qof_backend_set_error (be, ERR_FILEIO_PARSE_ERROR);
-		}
+			qof_error_set_be (be, parse_err);
 		return;
 	}
 	else if (is_qsf_object_be (params))
@@ -575,26 +598,23 @@ qsf_file_type (QofBackend * be, QofBook * book)
 		params->file_type = IS_QSF_OBJ;
 		result = load_qsf_object (book, path, params);
 		if (!result)
-		{
-			qof_backend_set_error (be, ERR_FILEIO_PARSE_ERROR);
-		}
+			qof_error_set_be (be, parse_err);
 		return;
 	}
-	err = qof_backend_get_error (be);
-	if (err == ERR_QSF_WRONG_MAP)
+	if (qof_error_check_be (be) == params->err_nomap)
 	{
 		/* usable QSF object but no map available */
 		params->file_type = IS_QSF_OBJ;
 		result = TRUE;
 	}
-	/* pop the error back on the stack. */
-	qof_backend_set_error (params->be, err);
 	if (result == FALSE)
 	{
 		if (is_qsf_map_be (params))
 		{
 			params->file_type = IS_QSF_MAP;
-			qof_backend_set_error (be, ERR_QSF_MAP_NOT_OBJ);
+			qof_error_set_be (be, qof_error_register
+			(_("The selected file '%s' is a QSF map and cannot "
+				"be opened as a QSF object."), TRUE));
 		}
 	}
 }
@@ -602,11 +622,11 @@ qsf_file_type (QofBackend * be, QofBook * book)
 static void
 qsf_object_sequence (QofParam * qof_param, gpointer data)
 {
-	qsf_param *params;
+	QsfParam *params;
 	GSList *checklist, *result;
 
 	g_return_if_fail (data != NULL);
-	params = (qsf_param *) data;
+	params = (QsfParam *) data;
 	result = NULL;
 	checklist = NULL;
 	params->knowntype = FALSE;
@@ -642,10 +662,10 @@ qsf_object_sequence (QofParam * qof_param, gpointer data)
 static void
 qsf_supported_parameters (gpointer type, gpointer user_data)
 {
-	qsf_param *params;
+	QsfParam *params;
 
 	g_return_if_fail (user_data != NULL);
-	params = (qsf_param *) user_data;
+	params = (QsfParam *) user_data;
 	params->qof_type = (QofIdType) type;
 	params->knowntype = FALSE;
 	qof_class_param_foreach (params->qof_obj_type, qsf_object_sequence,
@@ -685,59 +705,64 @@ kvp_value_to_qof_type_helper (KvpValueType n)
 {
 	switch (n)
 	{
-	case KVP_TYPE_GINT64:
+		case KVP_TYPE_GINT64:
 		{
 			return QOF_TYPE_INT64;
 			break;
 		}
-	case KVP_TYPE_DOUBLE:
+		case KVP_TYPE_DOUBLE:
 		{
 			return QOF_TYPE_DOUBLE;
 			break;
 		}
-	case KVP_TYPE_NUMERIC:
+		case KVP_TYPE_NUMERIC:
 		{
 			return QOF_TYPE_NUMERIC;
 			break;
 		}
-	case KVP_TYPE_STRING:
+		case KVP_TYPE_STRING:
 		{
 			return QOF_TYPE_STRING;
 			break;
 		}
-	case KVP_TYPE_GUID:
+		case KVP_TYPE_GUID:
 		{
 			return QOF_TYPE_GUID;
 			break;
 		}
 #ifndef QOF_DISABLE_DEPRECATED
-	case KVP_TYPE_TIMESPEC:
+		case KVP_TYPE_TIMESPEC:
 		{
 			return QOF_TYPE_DATE;
 			break;
 		}
 #endif
-	case KVP_TYPE_TIME :
+		case KVP_TYPE_BOOLEAN :
+		{
+			return QOF_TYPE_BOOLEAN;
+			break;
+		}
+		case KVP_TYPE_TIME :
 		{
 			return QOF_TYPE_TIME;
 			break;
 		}
-	case KVP_TYPE_BINARY:
+		case KVP_TYPE_BINARY:
 		{
 			return QSF_TYPE_BINARY;
 			break;
 		}
-	case KVP_TYPE_GLIST:
+		case KVP_TYPE_GLIST:
 		{
 			return QSF_TYPE_GLIST;
 			break;
 		}
-	case KVP_TYPE_FRAME:
+		case KVP_TYPE_FRAME:
 		{
 			return QSF_TYPE_FRAME;
 			break;
 		}
-	default:
+		default:
 		{
 			return NULL;
 		}
@@ -746,32 +771,34 @@ kvp_value_to_qof_type_helper (KvpValueType n)
 
 
 static void
-qsf_from_kvp_helper (const gchar * path, KvpValue * content, gpointer data)
+qsf_from_kvp_helper (const gchar * path, KvpValue * content, 
+					 gpointer data)
 {
-	qsf_param *params;
+	QsfParam *params;
 	QofParam *qof_param;
 	xmlNodePtr node;
 	KvpValueType n;
 	gchar *full_path;
 
-	params = (qsf_param *) data;
+	params = (QsfParam *) data;
 	qof_param = params->qof_param;
 	full_path = NULL;
 	g_return_if_fail (params && path && content);
 	n = kvp_value_get_type (content);
 	switch (n)
 	{
-	case KVP_TYPE_GINT64:
-	case KVP_TYPE_DOUBLE:
-	case KVP_TYPE_NUMERIC:
-	case KVP_TYPE_STRING:
-	case KVP_TYPE_GUID:
-	case KVP_TYPE_TIME :
+		case KVP_TYPE_GINT64:
+		case KVP_TYPE_DOUBLE:
+		case KVP_TYPE_NUMERIC:
+		case KVP_TYPE_STRING:
+		case KVP_TYPE_GUID:
+		case KVP_TYPE_TIME :
+		case KVP_TYPE_BOOLEAN :
 #ifndef QOF_DISABLE_DEPRECATED
-	case KVP_TYPE_TIMESPEC:
+		case KVP_TYPE_TIMESPEC:
 #endif
-	case KVP_TYPE_BINARY:
-	case KVP_TYPE_GLIST:
+		case KVP_TYPE_BINARY:
+		case KVP_TYPE_GLIST:
 		{
 			node =
 				xmlAddChild (params->output_node,
@@ -788,7 +815,7 @@ qsf_from_kvp_helper (const gchar * path, KvpValue * content, gpointer data)
 				BAD_CAST kvp_value_to_qof_type_helper (n));
 			break;
 		}
-	case KVP_TYPE_FRAME:
+		case KVP_TYPE_FRAME:
 		{
 			if (!params->full_kvp_path)
 				params->full_kvp_path = g_strdup (path);
@@ -801,7 +828,7 @@ qsf_from_kvp_helper (const gchar * path, KvpValue * content, gpointer data)
 			params->full_kvp_path = NULL;
 			break;
 		}
-	default:
+		default:
 		{
 			PERR (" unsupported value = %d", kvp_value_get_type (content));
 			break;
@@ -812,12 +839,12 @@ qsf_from_kvp_helper (const gchar * path, KvpValue * content, gpointer data)
 static void
 qsf_from_coll_cb (QofEntity * ent, gpointer user_data)
 {
-	qsf_param *params;
+	QsfParam *params;
 	QofParam *qof_param;
 	xmlNodePtr node;
 	gchar qsf_guid[GUID_ENCODING_LENGTH + 1];
 
-	params = (qsf_param *) user_data;
+	params = (QsfParam *) user_data;
 	if (!ent || !params)
 		return;
 	qof_param = params->qof_param;
@@ -877,19 +904,19 @@ reference_list_lookup (gpointer data, gpointer user_data)
 	QofEntity *ent;
 	QofParam *ref_param;
 	QofEntityReference *reference, *starter;
-	qsf_param *params;
+	QsfParam *params;
 	const GUID *guid;
 	xmlNodePtr node, object_node;
 	xmlNsPtr ns;
 	GList *copy_list;
 	gchar qsf_guid[GUID_ENCODING_LENGTH + 1], *ref_name;
 
-	params = (qsf_param *) user_data;
+	params = (QsfParam *) user_data;
 	ref_param = (QofParam *) data;
 	object_node = params->output_node;
 	ent = params->qsf_ent;
 	ns = params->qsf_ns;
-	starter = g_new (QofEntityReference, 1);
+	starter = g_new0 (QofEntityReference, 1);
 	starter->ent_guid = qof_entity_get_guid (ent);
 	starter->type = g_strdup (ent->e_type);
 	starter->param = ref_param;
@@ -937,7 +964,7 @@ qof_param holds the parameter sequence.
 static void
 qsf_entity_foreach (QofEntity * ent, gpointer data)
 {
-	qsf_param *params;
+	QsfParam *params;
 	GSList *param_list, *supported;
 	GList *ref;
 	xmlNodePtr node, object_node;
@@ -953,7 +980,7 @@ qsf_entity_foreach (QofEntity * ent, gpointer data)
 	gchar cm_sa[GUID_ENCODING_LENGTH + 1];
 
 	g_return_if_fail (data != NULL);
-	params = (qsf_param *) data;
+	params = (QsfParam *) data;
 	param_count = ++params->count;
 	ns = params->qsf_ns;
 	qsf_kvp = NULL;
@@ -1069,12 +1096,12 @@ qsf_entity_foreach (QofEntity * ent, gpointer data)
 static void
 qsf_foreach_obj_type (QofObject * qsf_obj, gpointer data)
 {
-	qsf_param *params;
+	QsfParam *params;
 	QofBook *book;
 	GSList *support;
 
 	g_return_if_fail (data != NULL);
-	params = (qsf_param *) data;
+	params = (QsfParam *) data;
 	/* Skip unsupported objects */
 	if ((qsf_obj->create == NULL) || (qsf_obj->foreach == NULL))
 	{
@@ -1094,7 +1121,7 @@ qsf_foreach_obj_type (QofObject * qsf_obj, gpointer data)
 =======================================================*/
 /*	QSF only uses one QofBook per file - count may be removed later. */
 static xmlDocPtr
-qofbook_to_qsf (QofBook * book, qsf_param * params)
+qofbook_to_qsf (QofBook * book, QsfParam * params)
 {
 	xmlNodePtr top_node, node;
 	xmlDocPtr doc;
@@ -1129,7 +1156,7 @@ qofbook_to_qsf (QofBook * book, qsf_param * params)
 
 static void
 write_qsf_from_book (const gchar *path, QofBook * book, 
-					 qsf_param * params)
+					 QsfParam * params)
 {
 	xmlDocPtr qsf_doc;
 	gint write_result;
@@ -1148,14 +1175,17 @@ write_qsf_from_book (const gchar *path, QofBook * book,
 		xmlSaveFormatFileEnc (path, qsf_doc, params->encoding, 1);
 	if (write_result < 0)
 	{
-		qof_backend_set_error (be, ERR_FILEIO_WRITE_ERROR);
+		qof_error_set_be (be, qof_error_register
+			(_("Could not write to '%s'. Check that you have "
+			 "permission to write to this file and that there is "
+			 "sufficient space to create it."), TRUE));
 		return;
 	}
 	qof_object_mark_clean (book);
 }
 
 static void
-write_qsf_to_stdout (QofBook * book, qsf_param * params)
+write_qsf_to_stdout (QofBook * book, QsfParam * params)
 {
 	xmlDocPtr qsf_doc;
 
@@ -1173,8 +1203,8 @@ static void
 qsf_write_file (QofBackend * be, QofBook * book)
 {
 	QSFBackend *qsf_be;
-	qsf_param *params;
-	char *path;
+	QsfParam *params;
+	gchar *path;
 
 	qsf_be = (QSFBackend *) be;
 	params = qsf_be->params;
@@ -1205,7 +1235,7 @@ string_to_kvp_value (const gchar * content, KvpValueType type)
 
 	switch (type)
 	{
-	case KVP_TYPE_GINT64:
+		case KVP_TYPE_GINT64:
 		{
 			errno = 0;
 			cm_i64 = strtoll (content, &tail, 0);
@@ -1215,56 +1245,52 @@ string_to_kvp_value (const gchar * content, KvpValueType type)
 			}
 			break;
 		}
-	case KVP_TYPE_DOUBLE:
+		case KVP_TYPE_DOUBLE:
 		{
 			errno = 0;
 			cm_double = strtod (content, &tail);
 			if (errno == 0)
-			{
 				return kvp_value_new_double (cm_double);
-			}
 			break;
 		}
-	case KVP_TYPE_NUMERIC:
+		case KVP_TYPE_NUMERIC:
 		{
 			qof_numeric_from_string (content, &cm_numeric);
-			return kvp_value_new_gnc_numeric (cm_numeric);
+			return kvp_value_new_numeric (cm_numeric);
 			break;
 		}
-	case KVP_TYPE_STRING:
+		case KVP_TYPE_STRING:
 		{
 			return kvp_value_new_string (content);
 			break;
 		}
-	case KVP_TYPE_GUID:
+		case KVP_TYPE_GUID:
 		{
-			cm_guid = g_new (GUID, 1);
+			cm_guid = g_new0 (GUID, 1);
 			if (TRUE == string_to_guid (content, cm_guid))
-			{
 				return kvp_value_new_guid (cm_guid);
-			}
 			break;
 		}
-	case KVP_TYPE_TIME :
-	{
-		QofDate *qd;
-		QofTime *qt;
-		KvpValue *retval;
-
-		qd = qof_date_parse (content, QOF_DATE_FORMAT_UTC);
-		if(qd)
+		case KVP_TYPE_TIME :
 		{
-			qt = qof_date_to_qtime (qd);
-			retval = kvp_value_new_time (qt);
-			qof_date_free (qd);
-			qof_time_free (qt);
-			return retval;
+			QofDate *qd;
+			QofTime *qt;
+			KvpValue *retval;
+
+			qd = qof_date_parse (content, QOF_DATE_FORMAT_UTC);
+			if(qd)
+			{
+				qt = qof_date_to_qtime (qd);
+				retval = kvp_value_new_time (qt);
+				qof_date_free (qd);
+				qof_time_free (qt);
+				return retval;
+			}
+			else
+				PERR (" failed to parse date");
 		}
-		else
-			PERR (" failed to parse date");
-	}
 #ifndef QOF_DISABLE_DEPRECATED
-	case KVP_TYPE_TIMESPEC:
+		case KVP_TYPE_TIMESPEC:
 		{
 			strptime (content, QSF_XSD_TIME, &kvp_time);
 			kvp_time_t = mktime (&kvp_time);
@@ -1273,16 +1299,22 @@ string_to_kvp_value (const gchar * content, KvpValueType type)
 			break;
 		}
 #endif
-	case KVP_TYPE_BINARY:
-//      return kvp_value_new_binary(value->value.binary.data,
+		case KVP_TYPE_BOOLEAN :
+		{
+			gboolean val;
+			val = qof_util_bool_to_int (content);
+			return kvp_value_new_boolean (val);
+		}
+		case KVP_TYPE_BINARY:
+//	      return kvp_value_new_binary(value->value.binary.data,
 //                                  value->value.binary.datasize);
-		break;
-	case KVP_TYPE_GLIST:
-//      return kvp_value_new_glist(value->value.list);
-		break;
-	case KVP_TYPE_FRAME:
-//      return kvp_value_new_frame(value->value.frame);
-		break;
+			break;
+		case KVP_TYPE_GLIST:
+//  	    return kvp_value_new_glist(value->value.list);
+			break;
+		case KVP_TYPE_FRAME:
+//	      return kvp_value_new_frame(value->value.frame);
+			break;
 	}
 	return NULL;
 }
@@ -1293,8 +1325,8 @@ string_to_kvp_value (const gchar * content, KvpValueType type)
 void
 qsf_object_commitCB (gpointer key, gpointer value, gpointer data)
 {
-	qsf_param *params;
-	qsf_objects *object_set;
+	QsfParam *params;
+	QsfObject *object_set;
 	xmlNodePtr node;
 	QofEntityReference *reference;
 	QofEntity *qsf_ent;
@@ -1325,7 +1357,7 @@ qsf_object_commitCB (gpointer key, gpointer value, gpointer data)
 	void (*char_setter) (QofEntity *, gchar);
 
 	g_return_if_fail (data && value && key);
-	params = (qsf_param *) data;
+	params = (QsfParam *) data;
 	node = (xmlNodePtr) value;
 	parameter_name = (const gchar *) key;
 	qof_type = (gchar *) node->name;
@@ -1431,11 +1463,15 @@ qsf_object_commitCB (gpointer key, gpointer value, gpointer data)
 	}
 	if (safe_strcmp (qof_type, QOF_TYPE_GUID) == 0)
 	{
-		cm_guid = g_new (GUID, 1);
+		cm_guid = g_new0 (GUID, 1);
 		if (TRUE !=
 			string_to_guid ((gchar *) xmlNodeGetContent (node), cm_guid))
 		{
-			qof_backend_set_error (params->be, ERR_QSF_BAD_OBJ_GUID);
+			qof_error_set_be (params->be, qof_error_register(
+			_("The selected QSF object file '%s' contains one or "
+			 "more invalid GUIDs. The file cannot be processed - "
+			 "please check the source of the file and try again."),
+			TRUE));
 			PINFO (" string to guid conversion failed for %s:%s:%s",
 				xmlNodeGetContent (node), obj_type, qof_type);
 			return;
@@ -1474,9 +1510,7 @@ qsf_object_commitCB (gpointer key, gpointer value, gpointer data)
 			}
 		}
 		else
-		{
-			qof_backend_set_error (params->be, ERR_QSF_OVERFLOW);
-		}
+			qof_error_set_be (params->be, params->err_overflow);
 	}
 	if (safe_strcmp (qof_type, QOF_TYPE_INT64) == 0)
 	{
@@ -1493,9 +1527,7 @@ qsf_object_commitCB (gpointer key, gpointer value, gpointer data)
 			}
 		}
 		else
-		{
-			qof_backend_set_error (params->be, ERR_QSF_OVERFLOW);
-		}
+			qof_error_set_be (params->be, params->err_overflow);
 	}
 	if (safe_strcmp (qof_type, QOF_TYPE_DOUBLE) == 0)
 	{
@@ -1516,13 +1548,9 @@ qsf_object_commitCB (gpointer key, gpointer value, gpointer data)
 	{
 		if (0 == safe_strcasecmp ((gchar *) xmlNodeGetContent (node),
 				QSF_XML_BOOLEAN_TEST))
-		{
 			cm_boolean = TRUE;
-		}
 		else
-		{
 			cm_boolean = FALSE;
-		}
 		boolean_setter = (void (*)(QofEntity *, gboolean)) cm_setter;
 		if (boolean_setter != NULL)
 		{
@@ -1537,9 +1565,7 @@ qsf_object_commitCB (gpointer key, gpointer value, gpointer data)
 			qsf_to_kvp_helper ((gchar *)
 			xmlGetProp (node, BAD_CAST QSF_OBJECT_VALUE));
 		if (!cm_type)
-		{
 			return;
-		}
 		qof_util_param_edit ((QofInstance *) qsf_ent, cm_param);
 		cm_value =
 			string_to_kvp_value ((gchar *) xmlNodeGetContent (node),
@@ -1559,11 +1585,15 @@ qsf_object_commitCB (gpointer key, gpointer value, gpointer data)
 		/* retrieve the *type* of the collection, ignore any contents. */
 		qsf_coll = cm_param->param_getfcn (qsf_ent, cm_param);
 		type = qof_collection_get_type (qsf_coll);
-		cm_guid = g_new (GUID, 1);
+		cm_guid = g_new0 (GUID, 1);
 		if (TRUE !=
 			string_to_guid ((gchar *) xmlNodeGetContent (node), cm_guid))
 		{
-			qof_backend_set_error (params->be, ERR_QSF_BAD_OBJ_GUID);
+			qof_error_set_be (params->be, (qof_error_register(
+			_("The selected QSF object file '%s' contains one or "
+			 "more invalid 'collect' values. The file cannot be processed - "
+			 "please check the source of the file and try again."),
+			TRUE)));
 			PINFO (" string to guid collect failed for %s",
 				xmlNodeGetContent (node));
 			return;
@@ -1606,7 +1636,7 @@ qsf_backend_new (void)
 	qsf_be = g_new0 (QSFBackend, 1);
 	be = (QofBackend *) qsf_be;
 	qof_backend_init (be);
-	qsf_be->params = g_new (qsf_param, 1);
+	qsf_be->params = g_new0 (QsfParam, 1);
 	qsf_be->params->be = be;
 	qsf_param_init (qsf_be->params);
 	qsf_be->be.session_begin = qsf_session_begin;
