@@ -20,14 +20,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
- 
-#define _GNU_SOURCE
+
 #include "config.h"
 #include <glib/gstdio.h>
 #include <sqlite.h>
 #include <glib.h>
+#include <libintl.h>
 #include "qof.h"
 
+#define _(String) dgettext (GETTEXT_PACKAGE, String)
 #define QOF_MOD_SQLITE "qof-sqlite-module"
 #define ACCESS_METHOD "sqlite"
 
@@ -46,27 +47,37 @@ static QofLogModule log_module = QOF_MOD_SQLITE;
 
 typedef enum
 {
-	SQL_NONE = 0,  /* no operation defined. init value. */
-	SQL_CREATE,    /* Create a new database */
-	SQL_LOAD,      /* Load all data from existing database. */
-	SQL_WRITE,     /* Write / sync all data to the database. */
-	SQL_INSERT,    /* Run a single INSERT statement. */
-	SQL_DELETE,    /* Run a single DELETE statement. */
-	SQL_UPDATE     /* Run a single UPDATE statement. */
-}qsql_statement_type;
+	/* no operation defined. init value. */
+	SQL_NONE = 0,
+	/* Create a new database */
+	SQL_CREATE,
+	/* Load all data from existing database. */
+	SQL_LOAD,
+	/* Write / sync all data to the database. */
+	SQL_WRITE,
+	/* Run a single INSERT statement. */
+	SQL_INSERT,
+	/* Run a single DELETE statement. */
+	SQL_DELETE,
+	/* Run a single UPDATE statement. */
+	SQL_UPDATE
+}QsqlStatementType;
 
 typedef struct
 {
 	QofBackend be;
 	sqlite *sqliteh;
-	qsql_statement_type stm_type;
+	QsqlStatementType stm_type;
 	gint dbversion;
+	gint create_handler;
+	gint delete_handler;
 	const gchar *fullpath;
 	gchar *err;
 	gchar *sql_str;
 	gboolean error;
 	QofIdType e_type;
 	QofBook * book;
+	QofErrorId err_delete, err_insert, err_update, err_create;
 } QSQLiteBackend;
 
 static gchar*
@@ -103,18 +114,32 @@ qsql_param_to_sql(QofParam *param)
 	return g_strdup_printf(" %s char(32)", param->param_name);
 }
 
-struct qsql_builder
+/** \brief QOF SQLite context
+
+Used to correlate the sqlite data with the
+live data.
+*/
+struct QsqlBuilder
 {
+	/** the current sqlite backend */
 	QSQLiteBackend *qsql_be;
+	/** the current entity */
 	QofEntity *ent;
+	/** the SQL string in use */
 	gchar *sql_str;
+	/** list of other dirty entities */
+	GList *dirty_list;
+	/** whether to use UPDATE or INSERT */
+	gboolean exists;
+	/** which parameter needs updating in sqlite. */
+	const QofParam * dirty;
 };
 
 static void
 create_param_list (QofParam *param, gpointer user_data)
 {
-	struct qsql_builder *qb;
-	qb = (struct qsql_builder*)user_data;
+	struct QsqlBuilder *qb;
+	qb = (struct QsqlBuilder *)user_data;
 
 	if (!g_str_has_suffix (qb->sql_str, "("))
 		qb->sql_str = g_strconcat (qb->sql_str, ", ", 
@@ -128,8 +153,8 @@ static void
 create_each_param (QofParam *param, gpointer user_data)
 {
 	gchar *value;
-	struct qsql_builder *qb;
-	qb = (struct qsql_builder*)user_data;
+	struct QsqlBuilder *qb;
+	qb = (struct QsqlBuilder *)user_data;
 
 	/** \todo handle KvpFrame */
 	value = qof_util_param_to_string (qb->ent, param);
@@ -180,7 +205,7 @@ delete_event (QofEntity *ent, QofEventId event_type,
 				NULL, qsql_be, &qsql_be->err) !=
 				SQLITE_OK)
 			{
-				qof_backend_set_error(be, ERR_BACKEND_SERVER_ERR);
+				qof_error_set_be (be, qsql_be->err_delete);
 				qsql_be->error = TRUE;
 				PERR (" %s", qsql_be->err);
 			}
@@ -196,7 +221,7 @@ create_event (QofEntity *ent, QofEventId event_type,
 			  gpointer handler_data, gpointer event_data)
 {
 	QofBackend *be;
-	struct qsql_builder qb;
+	struct QsqlBuilder qb;
 	QSQLiteBackend *qsql_be;
 
 	qsql_be = (QSQLiteBackend*)handler_data;
@@ -224,7 +249,7 @@ create_event (QofEntity *ent, QofEventId event_type,
 				NULL, qsql_be, &qsql_be->err) !=
 				SQLITE_OK)
 			{
-				qof_backend_set_error(be, ERR_BACKEND_SERVER_ERR);
+				qof_error_set_be (be, qsql_be->err_insert);
 				qsql_be->error = TRUE;
 				PERR (" %s", qsql_be->err);
 			}
@@ -240,7 +265,7 @@ create_event (QofEntity *ent, QofEventId event_type,
 static void
 qsql_modify (QofBackend *be, QofInstance *inst)
 {
-	struct qsql_builder qb;
+	struct QsqlBuilder qb;
 	QSQLiteBackend *qsql_be;
 	gchar gstr[GUID_ENCODING_LENGTH+1];
 	gchar * param_str;
@@ -255,7 +280,8 @@ qsql_modify (QofBackend *be, QofInstance *inst)
 	guid_to_string_buff (qof_instance_get_guid (inst), gstr);
 	qb.ent = (QofEntity*)inst;
 	param_str = qof_util_param_to_string (qb.ent, inst->param);
-	g_strescape (param_str, NULL);
+	if (param_str)
+		g_strescape (param_str, NULL);
 	qb.sql_str = g_strdup_printf ("UPDATE %s SET %s=\"",
 		qb.ent->e_type, inst->param->param_name);
 	qb.sql_str = g_strconcat (qb.sql_str, param_str, 
@@ -266,7 +292,7 @@ qsql_modify (QofBackend *be, QofInstance *inst)
 		NULL, qsql_be, &qsql_be->err) !=
 		SQLITE_OK)
 	{
-		qof_backend_set_error(be, ERR_BACKEND_SERVER_ERR);
+		qof_error_set_be (be, qsql_be->err_update);
 		qsql_be->error = TRUE;
 		PERR (" %s", qsql_be->err);
 	}
@@ -289,7 +315,6 @@ qsql_record_foreach(gpointer data, gint col_num, gchar **strings,
 	qof_event_suspend ();
 	inst = (QofInstance*)qof_object_new_instance (qsql_be->e_type,
 		qsql_be->book);
-	ENTER (" loading %s", qsql_be->e_type);
 	for(i = 0;i < col_num; i++)
 	{
 		/* get param and set as string */
@@ -312,10 +337,10 @@ qsql_record_foreach(gpointer data, gint col_num, gchar **strings,
 			qof_util_param_set_string (&inst->entity, param, strings[i]);
 	}
 	qof_event_resume ();
-	LEAVE (" ");
 	return SQLITE_OK;
 }
 
+/* used by create/insert */
 static void
 qsql_param_foreach(QofParam *param, gpointer data)
 {
@@ -329,83 +354,140 @@ qsql_param_foreach(QofParam *param, gpointer data)
 	g_free(p_str);
 }
 
-static gint 
-qsql_update_foreach (gpointer data, gint col_num, gchar **strings,
-					gchar **columnNames)
+static void
+update_param_foreach(QofParam *param, gpointer user_data)
+{
+	struct QsqlBuilder * qb;
+	gchar * value;
+
+	qb = (struct QsqlBuilder*) user_data;
+	if (param != qb->dirty)
+		return;
+	/* update table set name=val,name=val where guid=gstr; */
+	value = qof_util_param_to_string (qb->ent, param);
+	if (value)
+		g_strescape (value, NULL);
+	if (!value)
+		value = g_strdup ("");
+	if (g_str_has_suffix (qb->sql_str, " "))
+		qb->sql_str = g_strconcat (qb->sql_str, 
+		param->param_name, "=\"",  value, "\"", NULL);
+	else
+		qb->sql_str = g_strconcat (qb->sql_str, ",",
+		param->param_name, "=\"", value, "\"", NULL);
+}
+
+static void
+update_dirty (gpointer value, gpointer user_data)
 {
-	const QofParam * param;
 	QofInstance * inst;
-	struct qsql_builder * qb;
+	QofEntity * ent;
+	struct QsqlBuilder * qb;
 	QSQLiteBackend *qsql_be;
 	QofBackend * be;
 	gchar gstr[GUID_ENCODING_LENGTH+1];
 	gchar * param_str;
-	gint i;
 
-	qb = (struct qsql_builder*) data;
+	qb = (struct QsqlBuilder*) user_data;
 	qsql_be = qb->qsql_be;
 	be = (QofBackend*)qsql_be;
-	inst = (QofInstance*) qb->ent;
+	ent = (QofEntity*) value;
+	inst = (QofInstance*) ent;
 	if (!inst->dirty)
-		return SQLITE_OK;
+		return;
 	ENTER (" ");
-	guid_to_string_buff (qof_entity_get_guid (qb->ent), gstr);
-	for(i = 0;i < col_num; i++)
-	{
-		param = qof_class_get_parameter (qb->ent->e_type, 
-			columnNames[i]);
-		if (!param)
-			continue;
-		param_str = qof_util_param_to_string (qb->ent, param);
-		g_strescape (param_str, NULL);
-		qb->sql_str = g_strdup_printf ("UPDATE %s SET %s=\"",
-			qb->ent->e_type, param->param_name);
-		qb->sql_str = g_strconcat (qb->sql_str, param_str, 
-			"\" WHERE ", QOF_TYPE_GUID, "='", gstr, "';", NULL);
-		DEBUG (" sql_str=%s param_str=%s", qb->sql_str, param_str);
-		if(sqlite_exec (qsql_be->sqliteh, qb->sql_str, 
-			NULL, qsql_be, &qsql_be->err) != SQLITE_OK)
-		{
-			qof_backend_set_error(be, ERR_BACKEND_SERVER_ERR);
-			qsql_be->error = TRUE;
-			PERR (" %s", qsql_be->err);
-		}
-		else
-			inst->dirty = FALSE;
-	}
-	LEAVE (" ");
-	return SQLITE_OK;
-}
-
-static void
-check_state (QofEntity * ent, gpointer user_data)
-{
-	gchar gstr[GUID_ENCODING_LENGTH+1];
-	QSQLiteBackend *qsql_be;
-	struct qsql_builder qb;
-	QofBackend *be;
-
-	qsql_be = (QSQLiteBackend*) user_data;
-	be = (QofBackend*)qsql_be;
-	/* check if this entity already exists */
 	guid_to_string_buff (qof_entity_get_guid (ent), gstr);
-	qsql_be->sql_str = g_strdup_printf(
-		"SELECT * FROM %s where guid = \"%s\";", ent->e_type, gstr);
-	PINFO (" write: %s", qsql_be->sql_str);
-	qb.ent = ent;
-	/* update each dirty instance */
-	if(sqlite_exec (qsql_be->sqliteh, qsql_be->sql_str, 
-		qsql_update_foreach, &qb, &qsql_be->err) !=
-		SQLITE_OK)
+	/* qof_class_param_foreach  */
+	qb->sql_str = g_strdup_printf ("UPDATE %s SET ",
+		ent->e_type);
+	qof_class_param_foreach (ent->e_type, update_param_foreach, qb);
+	param_str = g_strdup_printf ("WHERE %s=\"%s\";",
+		QOF_TYPE_GUID, gstr);
+	qb->sql_str = g_strconcat (qb->sql_str, param_str, NULL);
+	g_free (param_str);
+	DEBUG (" update=%s", qb->sql_str);
+	if(sqlite_exec (qsql_be->sqliteh, qb->sql_str, 
+		NULL, qsql_be, &qsql_be->err) != SQLITE_OK)
 	{
-		qof_backend_set_error(be, ERR_BACKEND_SERVER_ERR);
+		qof_error_set_be (be, qsql_be->err_update);
 		qsql_be->error = TRUE;
 		PERR (" %s", qsql_be->err);
 	}
 	else
+		inst->dirty = FALSE;
+	LEAVE (" ");
+	return;
+}
+
+static gint
+create_dirty_list (gpointer data, gint col_num, gchar **strings,
+                   gchar **columnNames)
+{
+	struct QsqlBuilder * qb;
+	QofInstance * inst;
+	const QofParam * param;
+	gchar * value, *columnName, *tmp;
+
+	qb = (struct QsqlBuilder*) data;
+	/* qb->ent is the live data, strings is the sqlite data */
+	inst = (QofInstance*) qb->ent;
+	qb->exists = TRUE;
+	if (!inst->dirty)
+		return SQLITE_OK;
+	columnName = columnNames[col_num];
+	tmp = strings[col_num];
+	param = qof_class_get_parameter (qb->ent->e_type, columnName);
+	value = qof_util_param_to_string (qb->ent, param);
+	PINFO (" tmp=%s value=%s columnName=%s", tmp, value, columnName);
+	qb->dirty = param;
+	qb->dirty_list = g_list_prepend (qb->dirty_list, qb->ent);
+	DEBUG (" dirty_list=%d", g_list_length (qb->dirty_list));
+	return SQLITE_OK;
+}
+
+static gint
+mark_entity (gpointer data, gint col_num, gchar **strings,
+                   gchar **columnNames)
+{
+	struct QsqlBuilder * qb;
+
+	qb = (struct QsqlBuilder*) data;
+	qb->exists = TRUE;
+	DEBUG (" already exists");
+	return SQLITE_OK;
+}
+
+static void
+qsql_create (QofBackend *be, QofInstance *inst)
+{
+	gchar gstr[GUID_ENCODING_LENGTH+1];
+	QSQLiteBackend *qsql_be;
+	struct QsqlBuilder qb;
+	QofEntity * ent;
+
+	qsql_be = (QSQLiteBackend*)be;
+	if (!inst)
+		return;
+	ent = (QofEntity*) inst;	
+	guid_to_string_buff (qof_entity_get_guid (ent), gstr);
+	qb.sql_str = g_strdup_printf(
+		"SELECT * FROM %s where guid = \"%s\";", ent->e_type, gstr);
+	PINFO (" write: %s", qb.sql_str);
+	qb.ent = ent;
+	qb.dirty_list = NULL;
+	qb.exists = FALSE;
+	if(sqlite_exec (qsql_be->sqliteh, qb.sql_str, 
+		mark_entity, &qb, &qsql_be->err) !=
+		SQLITE_OK)
+	{
+		qof_error_set_be (be, qsql_be->err_update);
+		qsql_be->error = TRUE;
+		PERR (" %s", qsql_be->err);
+	}
+	if (!qb.exists)
 	{
 		/* create new entity */
-		g_free (qsql_be->sql_str);
+		PINFO (" insert");
 		qb.sql_str = g_strdup_printf ("INSERT into %s (", 
 			ent->e_type);
 		qof_class_param_foreach (ent->e_type, 
@@ -418,11 +500,75 @@ check_state (QofEntity * ent, gpointer user_data)
 		if(sqlite_exec (qsql_be->sqliteh, qb.sql_str, 
 			NULL, qsql_be, &qsql_be->err) != SQLITE_OK)
 		{
-			qof_backend_set_error(be, ERR_BACKEND_SERVER_ERR);
+			qof_error_set_be (be, qsql_be->err_insert);
 			qsql_be->error = TRUE;
 			PERR (" %s", qsql_be->err);
 		}
 	}
+	g_free (qb.sql_str);
+}
+
+static void
+check_state (QofEntity * ent, gpointer user_data)
+{
+	gchar gstr[GUID_ENCODING_LENGTH+1];
+	QSQLiteBackend *qsql_be;
+	struct QsqlBuilder qb;
+	QofBackend *be;
+	QofInstance * inst;
+
+	qsql_be = (QSQLiteBackend*) user_data;
+	be = (QofBackend*)qsql_be;
+	inst = (QofInstance*)ent;
+	if (!inst->dirty)
+		return;
+	/* check if this entity already exists */
+	guid_to_string_buff (qof_entity_get_guid (ent), gstr);
+	qb.sql_str = g_strdup_printf(
+		"SELECT * FROM %s where guid = \"%s\";", ent->e_type, gstr);
+	PINFO (" write: %s", qb.sql_str);
+	qb.ent = ent;
+	qb.dirty_list = NULL;
+	/* assume entity does not yet exist in backend,
+	e.g. being copied from another session. */
+	qb.exists = FALSE;
+	qb.qsql_be = qsql_be;
+	/* update each dirty instance */
+	/* Make a GList of dirty instances
+ 	Don't update during a SELECT, 
+ 	UPDATE will fail with DB_LOCKED */
+	if(sqlite_exec (qsql_be->sqliteh, qb.sql_str, 
+		create_dirty_list, &qb, &qsql_be->err) !=
+		SQLITE_OK)
+	{
+		qof_error_set_be (be, qsql_be->err_update);
+		qsql_be->error = TRUE;
+		PERR (" %s", qsql_be->err);
+	}
+	if (!qb.exists)
+	{
+		/* create new entity */
+		PINFO (" insert");
+		qb.sql_str = g_strdup_printf ("INSERT into %s (", 
+			ent->e_type);
+		qof_class_param_foreach (ent->e_type, 
+			create_param_list, &qb);
+		qb.sql_str = g_strconcat (qb.sql_str, ") VALUES (", NULL);
+		qof_class_param_foreach (ent->e_type, 
+			create_each_param, &qb);
+		qb.sql_str = g_strconcat (qb.sql_str, ");", NULL);
+		DEBUG (" sql_str= %s", qb.sql_str);
+		if(sqlite_exec (qsql_be->sqliteh, qb.sql_str, 
+			NULL, qsql_be, &qsql_be->err) != SQLITE_OK)
+		{
+			qof_error_set_be (be, qsql_be->err_insert);
+			qsql_be->error = TRUE;
+			PERR (" %s", qsql_be->err);
+		}
+	}
+	/* update instead */
+	g_list_foreach (qb.dirty_list, update_dirty, &qb);
+	g_free (qb.sql_str);
 }
 
 static void
@@ -455,10 +601,11 @@ qsql_class_foreach(QofObject *obj, gpointer data)
 			if(sqlite_exec (qsql_be->sqliteh, qsql_be->sql_str, 
 				NULL, NULL, &qsql_be->err) != SQLITE_OK)
 			{
-				qof_backend_set_error(be, ERR_BACKEND_DATA_CORRUPT);
+				qof_error_set_be (be, qsql_be->err_create);
 				qsql_be->error = TRUE;
 				PERR (" %s", qsql_be->err);
 			}
+			PINFO(" %s", qsql_be->sql_str);
 			g_free(qsql_be->sql_str);
 			break;
 		}
@@ -471,7 +618,6 @@ qsql_class_foreach(QofObject *obj, gpointer data)
 				qsql_record_foreach, qsql_be, &qsql_be->err) !=
 					SQLITE_OK)
 			{
-				qof_backend_set_error(be, ERR_BACKEND_SERVER_ERR);
 				qsql_be->error = TRUE;
 				PERR (" %s", qsql_be->err);
 			}
@@ -481,8 +627,6 @@ qsql_class_foreach(QofObject *obj, gpointer data)
 		{
 			if (!qof_book_not_saved (qsql_be->book))
 				break;
-			/* not all objects generate a create event
-			when the entity is created. */
 			qof_object_foreach (obj->e_type, qsql_be->book,
 				check_state, qsql_be);
 			break;
@@ -494,6 +638,7 @@ qsql_class_foreach(QofObject *obj, gpointer data)
 static void
 qsql_backend_createdb(QofBackend *be, QofSession *session)
 {
+	FILE * f;
 	QSQLiteBackend *qsql_be;
 
 	g_return_if_fail(be || session);
@@ -501,18 +646,30 @@ qsql_backend_createdb(QofBackend *be, QofSession *session)
 	qsql_be = (QSQLiteBackend*)be;
 	qsql_be->stm_type = SQL_CREATE;
 	qsql_be->book = qof_session_get_book (session);
-	qsql_be->sqliteh = sqlite_open (qsql_be->fullpath, 0, 
+	DEBUG (" create_file %s", qsql_be->fullpath);
+	f = fopen (qsql_be->fullpath, "a+");
+	if (f)
+		fclose (f);
+        else
+	{
+		qof_error_set (session, qof_error_register 
+			(_("Unable to open the output file '%s' - do you have "
+			"permission to create this file?"), TRUE));
+		qsql_be->error = TRUE;
+		LEAVE (" unable to create new file '%s'", 
+			qsql_be->fullpath);
+		return;
+	}
+	qsql_be->sqliteh = sqlite_open (qsql_be->fullpath, 0644, 
 		&qsql_be->err);
 	if(!qsql_be->sqliteh)
 	{
-		qof_backend_set_error(be, ERR_BACKEND_CANT_CONNECT);
+		qof_error_set_be (be, qsql_be->err_create);
 		qsql_be->error = TRUE;
-		PERR (" %s", qsql_be->err);
-		LEAVE (" ");
+		LEAVE (" %s", qsql_be->err);
 		return;
 	}
 	qof_object_foreach_type(qsql_class_foreach, qsql_be);
-	PINFO(" %s", qsql_be->sql_str);
 	LEAVE (" ");
 }
 
@@ -524,15 +681,16 @@ qsql_backend_opendb (QofBackend *be, QofSession *session)
 	g_return_if_fail(be || session);
 	ENTER (" ");
 	qsql_be = (QSQLiteBackend*)be;
-	qsql_be->sqliteh = sqlite_open (qsql_be->fullpath, 0, 
+	qsql_be->sqliteh = sqlite_open (qsql_be->fullpath, 0666, 
 		&qsql_be->err);
 	if(!qsql_be->sqliteh)
 	{
-		qof_backend_set_error(be, ERR_BACKEND_CANT_CONNECT);
+		qof_error_set_be (be, qof_error_register
+		(_("Unable to open the sqlite database '%s'."), TRUE));
 		qsql_be->error = TRUE;
 		PERR (" %s", qsql_be->err);
 	}
-	LEAVE (" ");
+	LEAVE (" %s", qsql_be->fullpath);
 }
 
 static void
@@ -549,10 +707,10 @@ qsqlite_session_begin(QofBackend *be, QofSession *session, const
 	ENTER (" book_path=%s", book_path);
 	qsql_be = (QSQLiteBackend*)be;
 	qsql_be->fullpath = NULL;
-	be->fullpath = g_strdup (book_path);
 	if(book_path == NULL)
 	{
-		qof_backend_set_error(be, ERR_BACKEND_BAD_URL);
+		qof_error_set_be (be, qof_error_register
+		(_("Please provide a filename for sqlite."), FALSE));
 		qsql_be->error = TRUE;
 		LEAVE (" bad URL");
 		return;
@@ -564,18 +722,24 @@ qsqlite_session_begin(QofBackend *be, QofSession *session, const
 		qsql_be->fullpath = g_strdup(pp[1]);
 		g_strfreev (pp);
 	}
+	else
+		qsql_be->fullpath = g_strdup (book_path);
+	be->fullpath = g_strdup (qsql_be->fullpath);
+	PINFO (" final path = %s", qsql_be->fullpath);
 	stat_val = g_stat (qsql_be->fullpath, &statinfo);
 	if (!S_ISREG (statinfo.st_mode) || statinfo.st_size == 0)
 		qsql_backend_createdb (be, session);
-	qsql_backend_opendb (be, session);
-	if(qsql_be->error) 
-	{ 
+	if (!qsql_be->error)
+		qsql_backend_opendb (be, session);
+	if(qof_error_check_be (be) || qsql_be->error) 
+	{
 		LEAVE(" open failed"); 
 		return; 
 	}
-	qof_backend_set_error(be, ERR_BACKEND_NO_ERR);
-	qof_event_register_handler (create_event, qsql_be);
-	qof_event_register_handler (delete_event, qsql_be);
+	qsql_be->create_handler = 
+		qof_event_register_handler (create_event, qsql_be);
+	qsql_be->delete_handler = 
+		qof_event_register_handler (delete_event, qsql_be);
 	LEAVE (" db=%s", qsql_be->fullpath);
 }
 
@@ -610,6 +774,8 @@ qsqlite_write_db (QofBackend *be, QofBook *book)
 static gboolean
 qsql_determine_file_type (const gchar *path)
 {
+	if (!path)
+		return FALSE;
 	return TRUE;
 }
 
@@ -627,7 +793,14 @@ qsqlite_session_end (QofBackend *be)
 static void
 qsqlite_destroy_backend (QofBackend *be)
 {
+	QSQLiteBackend *qsql_be;
+
+	g_return_if_fail(be);
+	qsql_be = (QSQLiteBackend*)be;
+	qof_event_unregister_handler (qsql_be->create_handler);
+	qof_event_unregister_handler (qsql_be->delete_handler);
 	g_free (be);
+	g_free (qsql_be);
 }
 
 static void
@@ -650,13 +823,24 @@ qsql_backend_new(void)
 	qof_backend_init(be);
 	qsql_be->dbversion = QOF_OBJECT_VERSION;
 	qsql_be->stm_type = SQL_NONE;
+	qsql_be->err_delete = qof_error_register
+		(_("Unable to delete record."), FALSE);
+	qsql_be->err_create = qof_error_register
+		(_("Unable to create record."), FALSE);
+	qsql_be->err_insert = qof_error_register
+		(_("Unable to insert a new record."), FALSE);
+	qsql_be->err_update = qof_error_register
+		(_("Unable to update existing record."), FALSE);
+
 	be->session_begin = qsqlite_session_begin;
 
 	be->session_end = qsqlite_session_end;
 	be->destroy_backend = qsqlite_destroy_backend;
 	be->load = qsqlite_db_load;
 	be->save_may_clobber_data = NULL;
-	be->begin = NULL;
+	/* begin: create an empty entity is none exists,
+	even if events are suspended. */
+	be->begin = qsql_create;
 	/* commit: write to sqlite, commit undo record. */
 	be->commit = qsql_modify;
 	be->rollback = NULL;
@@ -683,7 +867,7 @@ void qof_sqlite_provider_init(void)
 
 	ENTER (" ");
 	prov = g_new0 (QofBackendProvider, 1);
-	prov->provider_name = "QOF SQLite Backend Version 0.1";
+	prov->provider_name = "QOF SQLite Backend Version 0.2";
 	prov->access_method = ACCESS_METHOD;
 	prov->partial_book_supported = TRUE;
 	prov->backend_new = qsql_backend_new;
