@@ -39,12 +39,16 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <glib.h>
+#include <libintl.h>
 #include "qof.h"
+#include "qoferror-p.h"
 #include "qofbackend-p.h"
 #include "qofbook-p.h"
 #include "qofsession-p.h"
 #include "qofobject-p.h"
 
+#define _(String) dgettext (GETTEXT_PACKAGE, String)
+
 static GHookList *session_closed_hooks = NULL;
 static QofLogModule log_module = QOF_MOD_SESSION;
 static GSList *provider_list = NULL;
@@ -99,96 +103,6 @@ qof_session_call_close_hooks (QofSession * session)
 	}
 }
 
-/* ============================================================= */
-/* error handling routines */
-
-static void
-qof_session_clear_error (QofSession * session)
-{
-	QofBackendError err;
-
-	session->last_err = ERR_BACKEND_NO_ERR;
-	g_free (session->error_message);
-	session->error_message = NULL;
-
-	/* pop the stack on the backend as well. */
-	if (session->backend)
-	{
-		do
-		{
-			err = qof_backend_get_error (session->backend);
-		}
-		while (ERR_BACKEND_NO_ERR != err);
-	}
-}
-
-void
-qof_session_push_error (QofSession * session, QofBackendError err,
-	const gchar *message)
-{
-	if (!session)
-		return;
-
-	g_free (session->error_message);
-
-	session->last_err = err;
-	session->error_message = g_strdup (message);
-}
-
-QofBackendError
-qof_session_get_error (QofSession * session)
-{
-	QofBackendError err;
-
-	if (!session)
-		return ERR_BACKEND_NO_BACKEND;
-
-	/* if we have a local error, return that. */
-	if (ERR_BACKEND_NO_ERR != session->last_err)
-	{
-		return session->last_err;
-	}
-
-	/* maybe we should return a no-backend error ??? */
-	if (!session->backend)
-		return ERR_BACKEND_NO_ERR;
-
-	err = qof_backend_get_error (session->backend);
-	session->last_err = err;
-	return err;
-}
-
-static const gchar *
-get_default_error_message (QofBackendError err 
-						   __attribute__ ((unused)))
-{
-	return "";
-}
-
-const gchar *
-qof_session_get_error_message (QofSession * session)
-{
-	if (!session)
-		return "";
-	if (!session->error_message)
-		return get_default_error_message (session->last_err);
-	return session->error_message;
-}
-
-QofBackendError
-qof_session_pop_error (QofSession * session)
-{
-	QofBackendError err;
-
-	if (!session)
-		return ERR_BACKEND_NO_BACKEND;
-
-	err = qof_session_get_error (session);
-	qof_session_clear_error (session);
-
-	return err;
-}
-
 /* =============================================================== */
 
 static void
@@ -197,12 +111,13 @@ qof_session_init (QofSession * session)
 	if (!session)
 		return;
 
+#ifndef QOF_DISABLE_DEPRECATED
 	session->entity.e_type = QOF_ID_SESSION;
+#endif
 	session->books = g_list_append (NULL, qof_book_new ());
 	session->book_id = NULL;
 	session->backend = NULL;
-
-	qof_session_clear_error (session);
+	qof_error_init ();
 }
 
 QofSession *
@@ -775,9 +690,7 @@ qof_entity_copy_list (QofSession * new_session, GList * entity_list)
 	QofEntityCopyData *qecd;
 
 	if (!new_session || !entity_list)
-	{
 		return FALSE;
-	}
 	ENTER (" list=%d", g_list_length (entity_list));
 	qecd = g_new0 (QofEntityCopyData, 1);
 	qof_event_suspend ();
@@ -787,9 +700,7 @@ qof_entity_copy_list (QofSession * new_session, GList * entity_list)
 	g_list_foreach (entity_list, qof_entity_list_foreach, qecd);
 	qof_event_resume ();
 	if (qecd->error)
-	{
 		PWARN (" some/all entities in the list could not be copied.");
-	}
 	g_free (qecd);
 	LEAVE (" ");
 	return TRUE;
@@ -1042,6 +953,7 @@ and use JUST the module name without .so - .so is not portable! */
 struct backend_providers backend_list[] = {
 	{QOF_LIB_DIR, QSF_BACKEND_LIB, QSF_MODULE_INIT},
 	{QOF_LIB_DIR, "libqof-backend-sqlite", "qof_sqlite_provider_init"},
+/*	{QOF_LIB_DIR, "libqof-backend-gda", "qof_gda_provider_init"},*/
 #ifdef HAVE_DWI
 	{QOF_LIB_DIR, "libqof_backend_dwi", "dwiend_provider_init"},
 #endif
@@ -1055,10 +967,9 @@ qof_session_load_backend (QofSession * session, gchar *access_method)
 	GList *node;
 	QofBackendProvider *prov;
 	QofBook *book;
-	gchar *msg;
 	gint num;
 	gboolean prov_type;
-	gboolean (*type_check) (const char *);
+	gboolean (*type_check) (const gchar *);
 
 	ENTER (" list=%d", g_slist_length (provider_list));
 	prov_type = FALSE;
@@ -1114,10 +1025,6 @@ qof_session_load_backend (QofSession * session, gchar *access_method)
 		}
 		p = p->next;
 	}
-	msg =
-		g_strdup_printf ("failed to load '%s' using access_method",
-		access_method);
-	qof_session_push_error (session, ERR_BACKEND_NO_HANDLER, msg);
 	LEAVE (" ");
 }
 
@@ -1130,10 +1037,6 @@ qof_session_destroy_backend (QofSession * session)
 
 	if (session->backend)
 	{
-		/* clear any error message */
-		char *msg = qof_backend_get_message (session->backend);
-		g_free (msg);
-
 		/* Then destroy the backend */
 		if (session->backend->destroy_backend)
 		{
@@ -1152,8 +1055,7 @@ void
 qof_session_begin (QofSession * session, const gchar *book_id,
 	gboolean ignore_lock, gboolean create_if_nonexistent)
 {
-	gchar *p, *access_method, *msg;
-	gint err;
+	gchar *p, *access_method;
 
 	if (!session)
 		return;
@@ -1162,21 +1064,20 @@ qof_session_begin (QofSession * session, const gchar *book_id,
 		session, ignore_lock, book_id ? book_id : "(null)");
 
 	/* Clear the error condition of previous errors */
-	qof_session_clear_error (session);
+	qof_error_clear (session);
 
 	/* Check to see if this session is already open */
 	if (session->book_id)
 	{
-		qof_session_push_error (session, ERR_BACKEND_LOCKED, NULL);
+		qof_error_set (session, qof_error_register
+		(_("This book appears to be open already."), FALSE));
 		LEAVE (" push error book is already open ");
 		return;
 	}
 
-	/* seriously invalid */
 	if (!book_id)
 	{
-		qof_session_push_error (session, ERR_BACKEND_BAD_URL, NULL);
-		LEAVE (" push error missing book_id");
+		LEAVE (" using stdout");
 		return;
 	}
 
@@ -1208,36 +1109,36 @@ qof_session_begin (QofSession * session, const gchar *book_id,
 	/* No backend was found. That's bad. */
 	if (NULL == session->backend)
 	{
-		qof_session_push_error (session, ERR_BACKEND_BAD_URL, NULL);
+		gchar * msg;
+
+		msg = g_strdup_printf (_("Unable to locate a "
+		"suitable backend for '%s' - please check "
+		"you have specified an access method "
+		"like file: or sqlite:"), book_id);
+		qof_error_set (session, qof_error_register
+			(msg, FALSE));
+		DEBUG (" msg=%s", msg);
 		LEAVE (" BAD: no backend: sess=%p book-id=%s",
 			session, book_id ? book_id : "(null)");
+		g_free (msg);
 		return;
 	}
 
 	/* If there's a begin method, call that. */
 	if (session->backend->session_begin)
 	{
-
 		(session->backend->session_begin) (session->backend, session,
 			session->book_id, ignore_lock, create_if_nonexistent);
 		PINFO (" Done running session_begin on backend");
-		err = qof_backend_get_error (session->backend);
-		msg = qof_backend_get_message (session->backend);
-		if (err != ERR_BACKEND_NO_ERR)
+		if (qof_error_check(session) != QOF_SUCCESS)
 		{
 			g_free (session->book_id);
 			session->book_id = NULL;
-			qof_session_push_error (session, err, msg);
-			LEAVE (" backend error %d %s", err, msg);
+			LEAVE (" backend error ");
 			return;
 		}
-		if (msg != NULL)
-		{
-			PWARN (" %s", msg);
-			g_free (msg);
-		}
 	}
-
+	qof_error_clear (session);
 	LEAVE (" sess=%p book-id=%s", session, book_id ? book_id : "(null)");
 }
 
@@ -1249,11 +1150,11 @@ qof_session_load (QofSession * session, QofPercentageFunc percentage_func)
 	QofBook *newbook, *ob;
 	QofBookList *oldbooks, *node;
 	QofBackend *be;
-	QofBackendError err;
 
 	if (!session)
 		return;
-	if (!session->book_id)
+	if ((!session->book_id) ||
+		(0 == safe_strcasecmp(session->book_id, QOF_STDOUT)))
 		return;
 
 	ENTER (" sess=%p book_id=%s", session, session->book_id
@@ -1272,7 +1173,7 @@ qof_session_load (QofSession * session, QofPercentageFunc percentage_func)
 	session->books = g_list_append (NULL, newbook);
 	PINFO (" new book=%p", newbook);
 
-	qof_session_clear_error (session);
+	qof_error_clear (session);
 
 	/* This code should be sufficient to initialize *any* backend,
 	 * whether http, postgres, or anything else that might come along.
@@ -1295,27 +1196,19 @@ qof_session_load (QofSession * session, QofPercentageFunc percentage_func)
 		if (be->load)
 		{
 			be->load (be, newbook);
-			qof_session_push_error (session, qof_backend_get_error (be),
-				NULL);
 		}
 	}
 
-	/* XXX if the load fails, then we try to restore the old set of books;
-	 * however, we don't undo the session id (the URL).  Thus if the 
-	 * user attempts to save after a failed load, they weill be trying to 
-	 * save to some bogus URL.   This is wrong. XXX  FIXME.
-	 */
-	err = qof_session_get_error (session);
-	if ((err != ERR_BACKEND_NO_ERR) &&
-		(err != ERR_FILEIO_FILE_TOO_OLD) &&
-		(err != ERR_FILEIO_NO_ENCODING) && (err != ERR_SQL_DB_TOO_OLD))
+	if (qof_error_check(session) != QOF_SUCCESS)
 	{
 		/* Something broke, put back the old stuff */
 		qof_book_set_backend (newbook, NULL);
 		qof_book_destroy (newbook);
 		g_list_free (session->books);
 		session->books = oldbooks;
-		LEAVE (" error from backend %d", qof_session_get_error (session));
+		g_free (session->book_id);
+		session->book_id = NULL;
+		LEAVE (" error from backend ");
 		return;
 	}
 
@@ -1346,20 +1239,6 @@ qof_session_save_may_clobber_data (QofSession * session)
 	return (*(session->backend->save_may_clobber_data)) (session->backend);
 }
 
-static gboolean
-save_error_handler (QofBackend * be, QofSession * session)
-{
-	int err;
-	err = qof_backend_get_error (be);
-
-	if (ERR_BACKEND_NO_ERR != err)
-	{
-		qof_session_push_error (session, err, NULL);
-		return TRUE;
-	}
-	return FALSE;
-}
-
 void
 qof_session_save (QofSession * session, 
 				  QofPercentageFunc percentage_func)
@@ -1370,7 +1249,6 @@ qof_session_save (QofSession * session,
 	QofBackendProvider *prov;
 	GSList *p;
 	QofBook *book, *abook;
-	gint err;
 	gint num;
 	gchar *msg, *book_id;
 
@@ -1445,21 +1323,13 @@ qof_session_save (QofSession * session,
 						session, book_id, TRUE, TRUE);
 					PINFO
 						(" Done running session_begin on changed backend");
-					err = qof_backend_get_error (session->backend);
-					msg = qof_backend_get_message (session->backend);
-					if (err != ERR_BACKEND_NO_ERR)
+					if (qof_error_check (session) != QOF_SUCCESS)
 					{
 						g_free (session->book_id);
 						session->book_id = NULL;
-						qof_session_push_error (session, err, msg);
-						LEAVE (" changed backend error %d", err);
+						LEAVE (" changed backend error");
 						return;
 					}
-					if (msg != NULL)
-					{
-						PWARN ("%s", msg);
-						g_free (msg);
-					}
 				}
 				/* Tell the books about the backend that they'll be using. */
 				for (node = session->books; node; node = node->next)
@@ -1477,7 +1347,9 @@ qof_session_save (QofSession * session,
 		if (!session->backend)
 		{
 			msg = g_strdup_printf (" failed to load backend");
-			qof_session_push_error (session, ERR_BACKEND_NO_HANDLER, msg);
+			qof_error_set (session, qof_error_register
+			(_("Failed to load backend, no suitable handler."), 
+			FALSE));
 			return;
 		}
 	}
@@ -1500,23 +1372,21 @@ qof_session_save (QofSession * session,
 			qof_book_set_backend (abook, be);
 			be->percentage = percentage_func;
 			if (be->sync)
-			{
 				(be->sync) (be, abook);
-				if (save_error_handler (be, session))
-					return;
-			}
 		}
 		/* If we got to here, then the backend saved everything 
 		 * just fine, and we are done. So return. */
 		/* Return the book_id to previous value. */
-		qof_session_clear_error (session);
+		qof_error_clear (session);
 		LEAVE (" Success");
 		return;
 	}
 	else
 	{
 		msg = g_strdup_printf (" failed to load backend");
-		qof_session_push_error (session, ERR_BACKEND_NO_HANDLER, msg);
+		qof_error_set (session, qof_error_register
+			(_("Failed to load backend, no suitable handler."), 
+			FALSE));
 	}
 	LEAVE (" error -- No backend!");
 }
@@ -1538,7 +1408,7 @@ qof_session_end (QofSession * session)
 		(session->backend->session_end) (session->backend);
 	}
 
-	qof_session_clear_error (session);
+	qof_error_clear (session);
 
 	g_free (session->book_id);
 	session->book_id = NULL;
@@ -1575,6 +1445,7 @@ qof_session_destroy (QofSession * session)
 		qof_session_clear_current_session();
 #endif
 	g_free (session);
+	qof_error_close ();
 
 	LEAVE (" sess=%p", session);
 }
