@@ -30,7 +30,8 @@
 #include "config.h"
 #include <stdlib.h>				/* for working atoll */
 #include <errno.h>
-#include "glib.h"
+#include <glib.h>
+#include <libintl.h>
 #ifdef HAVE_GDA
 #include <sql/sql_parser.h>
 #else
@@ -40,6 +41,8 @@
 #include "qof.h"
 #include "qofquery-p.h"
 
+#define _(String) dgettext (GETTEXT_PACKAGE, String)
+
 static QofLogModule log_module = QOF_MOD_QUERY;
 
 /* =================================================================== */
@@ -235,17 +238,17 @@ handle_single_condition (QofSqlQuery * query, sql_condition * cond)
 		switch (kvt)
 		{
 		case KVP_TYPE_GINT64:
-			{
+		{
 				gint64 ival = kvp_value_get_gint64 (kv);
 				sprintf (tmpbuff, "%" G_GINT64_FORMAT "\n", ival);
 				break;
-			}
+		}
 		case KVP_TYPE_DOUBLE:
-			{
+		{
 				double ival = kvp_value_get_double (kv);
 				sprintf (tmpbuff, "%26.18g\n", ival);
 				break;
-			}
+		}
 		case KVP_TYPE_STRING:
 			/* If there's no value, its not an error; 
 			 * we just don't do this predicate */
@@ -258,6 +261,7 @@ handle_single_condition (QofSqlQuery * query, sql_condition * cond)
 #ifndef QOF_DISABLE_DEPRECATED
 		case KVP_TYPE_TIMESPEC:
 #endif
+		case KVP_TYPE_BOOLEAN :
 		case KVP_TYPE_BINARY:
 		case KVP_TYPE_GLIST:
 		case KVP_TYPE_NUMERIC:
@@ -750,7 +754,11 @@ qof_sql_insertCB (const QofParam * param, const gchar * insert_string,
 
 			book = qof_instance_get_book ((QofInstance *) ent);
 			backend = qof_book_get_backend (book);
-			qof_backend_set_error (backend, ERR_QSF_OVERFLOW);
+			qof_error_set_be (backend, qof_error_register 
+			(_("When converting SQLite strings into numbers, an "
+			"overflow has been detected. The SQLite database "
+			"'%s' contains invalid data in a field that is meant "
+			"to hold a number."), TRUE));
 		}
 	}
 	if (safe_strcmp (param->param_type, QOF_TYPE_INT64) == 0)
@@ -773,7 +781,11 @@ qof_sql_insertCB (const QofParam * param, const gchar * insert_string,
 
 			book = qof_instance_get_book ((QofInstance *) ent);
 			backend = qof_book_get_backend (book);
-			qof_backend_set_error (backend, ERR_QSF_OVERFLOW);
+			qof_error_set_be (backend, qof_error_register 
+			(_("When converting SQLite strings into numbers, an "
+			"overflow has been detected. The SQLite database "
+			"'%s' contains invalid data in a field that is meant "
+			"to hold a number."), TRUE));
 		}
 	}
 	if (safe_strcmp (param->param_type, QOF_TYPE_DOUBLE) == 0)
