@@ -32,6 +32,7 @@
 #include <glib.h>
 #include <stdlib.h>
 #include <string.h>
+#include <math.h>
 #include "qof.h"
 #include "qofundo-p.h"
 #include "qofbook-p.h"
@@ -107,7 +108,7 @@ safe_strcasecmp (const gchar * da, const gchar * db)
 	return 0;
 }
 
-gint
+inline gint
 null_strcmp (const gchar * da, const gchar * db)
 {
 	if (da && db)
@@ -174,6 +175,18 @@ ultostr (gulong val, gint base)
 	return g_strdup (buf);
 }
 
+inline gint
+qof_util_double_compare (gdouble d1, gdouble d2)
+{
+	if (isnan (d1) && isnan (d2))
+		return 0;
+	if (d1 < d2)
+		return -1;
+	if (d1 > d2)
+		return 1;
+	return 0;
+}
+
 /* =================================================================== */
 /* returns TRUE if the string is a number, possibly with whitespace */
 /* =================================================================== */
@@ -301,29 +314,12 @@ qof_util_param_commit (QofInstance * inst, const QofParam * param)
 	if (0 < inst->editlevel)
 		return FALSE;
 	be = qof_book_get_backend (inst->book);
+	inst->param = param;
 	if (be && qof_backend_commit_exists (be))
-	{
-		QofBackendError errcode;
-
-		do
-		{
-			errcode = qof_backend_get_error (be);
-		}
-		while (ERR_BACKEND_NO_ERR != errcode);
-
 		qof_backend_run_commit (be, inst);
-		errcode = qof_backend_get_error (be);
-		if (ERR_BACKEND_NO_ERR != errcode)
-		{
-			/* Push error back onto the stack */
-			qof_backend_set_error (be, errcode);
-			return FALSE;
-		}
-	}
 	if (param != NULL)
 	{
 		undo_data = inst->book->undo_data;
-		inst->param = param;
 		if (undo_data->undo_operation_open)
 			qof_undo_commit (inst, param);
 	}
@@ -417,8 +413,7 @@ gpointer
 qof_util_string_cache_insert (gconstpointer key)
 {
 	if (key)
-		return g_cache_insert (qof_util_get_string_cache (),
-			(gpointer) key);
+		return g_cache_insert(qof_util_get_string_cache(), (gpointer)key);
 	return NULL;
 }
 
